@@ -25,6 +25,7 @@ use crate::location::store::{Location, LocationAttribute, LocationList};
 use crate::paging::Paging;
 
 use diesel::prelude::*;
+use std::convert::TryInto;
 
 pub(in crate::location::store::diesel) trait LocationStoreListLocationsOperation<C: Connection> {
     fn list_locations(
@@ -72,6 +73,10 @@ impl<'a> LocationStoreListLocationsOperation<diesel::pg::PgConnection>
                 LocationStoreError::InternalError(InternalError::from_source(Box::new(err)))
             })?;
 
+            let total = locs.len().try_into().map_err(|err| {
+                LocationStoreError::InternalError(InternalError::from_source(Box::new(err)))
+            })?;
+
             let mut locations = Vec::new();
 
             for l in locs {
@@ -83,16 +88,6 @@ impl<'a> LocationStoreListLocationsOperation<diesel::pg::PgConnection>
                 locations.push(Location::from((loc, attrs)));
             }
 
-            let mut count_query = location::table.into_boxed().select(location::all_columns);
-
-            if let Some(service_id) = service_id {
-                count_query = count_query.filter(location::service_id.eq(service_id));
-            } else {
-                count_query = count_query.filter(location::service_id.is_null());
-            }
-
-            let total = count_query.count().get_result(self.conn)?;
-
             Ok(LocationList::new(
                 locations,
                 Paging::new(offset, limit, total),
@@ -190,6 +185,10 @@ impl<'a> LocationStoreListLocationsOperation<diesel::sqlite::SqliteConnection>
                 LocationStoreError::InternalError(InternalError::from_source(Box::new(err)))
             })?;
 
+            let total = locs.len().try_into().map_err(|err| {
+                LocationStoreError::InternalError(InternalError::from_source(Box::new(err)))
+            })?;
+
             let mut locations = Vec::new();
 
             for l in locs {
@@ -201,16 +200,6 @@ impl<'a> LocationStoreListLocationsOperation<diesel::sqlite::SqliteConnection>
                 locations.push(Location::from((loc, attrs)));
             }
 
-            let mut count_query = location::table.into_boxed().select(location::all_columns);
-
-            if let Some(service_id) = service_id {
-                count_query = count_query.filter(location::service_id.eq(service_id));
-            } else {
-                count_query = count_query.filter(location::service_id.is_null());
-            }
-
-            let total = count_query.count().get_result(self.conn)?;
-
             Ok(LocationList::new(
                 locations,
                 Paging::new(offset, limit, total),
