@@ -80,8 +80,8 @@ impl FromProto<protos::pike_payload::CreateAgentAction> for CreateAgentAction {
             roles: create_agent.get_roles().to_vec(),
             metadata: create_agent
                 .get_metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::from_proto)
                 .collect::<Result<Vec<KeyValueEntry>, ProtoConversionError>>()?,
         })
@@ -100,8 +100,8 @@ impl FromNative<CreateAgentAction> for protos::pike_payload::CreateAgentAction {
         proto_create_agent.set_metadata(RepeatedField::from_vec(
             create_agent
                 .metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::into_proto)
                 .collect::<Result<Vec<protos::pike_state::KeyValueEntry>, ProtoConversionError>>(
                 )?,
@@ -244,8 +244,8 @@ impl FromProto<protos::pike_payload::UpdateAgentAction> for UpdateAgentAction {
             roles: update_agent.get_roles().to_vec(),
             metadata: update_agent
                 .get_metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::from_proto)
                 .collect::<Result<Vec<KeyValueEntry>, ProtoConversionError>>()?,
         })
@@ -264,8 +264,8 @@ impl FromNative<UpdateAgentAction> for protos::pike_payload::UpdateAgentAction {
         proto_update_agent.set_metadata(RepeatedField::from_vec(
             update_agent
                 .metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::into_proto)
                 .collect::<Result<Vec<protos::pike_state::KeyValueEntry>, ProtoConversionError>>(
                 )?,
@@ -499,14 +499,14 @@ impl FromProto<protos::pike_payload::CreateOrganizationAction> for CreateOrganiz
             name: create_org.get_name().to_string(),
             alternate_ids: create_org
                 .get_alternate_ids()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(AlternateId::from_proto)
                 .collect::<Result<Vec<AlternateId>, ProtoConversionError>>()?,
             metadata: create_org
                 .get_metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::from_proto)
                 .collect::<Result<Vec<KeyValueEntry>, ProtoConversionError>>()?,
         })
@@ -522,16 +522,16 @@ impl FromNative<CreateOrganizationAction> for protos::pike_payload::CreateOrgani
         proto_create_org.set_alternate_ids(RepeatedField::from_vec(
             create_org
                 .alternate_ids()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(AlternateId::into_proto)
                 .collect::<Result<Vec<protos::pike_state::AlternateId>, ProtoConversionError>>()?,
         ));
         proto_create_org.set_metadata(RepeatedField::from_vec(
             create_org
                 .metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::into_proto)
                 .collect::<Result<Vec<protos::pike_state::KeyValueEntry>, ProtoConversionError>>(
                 )?,
@@ -670,15 +670,15 @@ impl FromProto<protos::pike_payload::UpdateOrganizationAction> for UpdateOrganiz
             name: update_org.get_name().to_string(),
             alternate_ids: update_org
                 .get_alternate_ids()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(AlternateId::from_proto)
                 .collect::<Result<Vec<AlternateId>, ProtoConversionError>>()?,
             locations: update_org.get_locations().to_vec(),
             metadata: update_org
                 .get_metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::from_proto)
                 .collect::<Result<Vec<KeyValueEntry>, ProtoConversionError>>()?,
         })
@@ -694,8 +694,8 @@ impl FromNative<UpdateOrganizationAction> for protos::pike_payload::UpdateOrgani
         proto_update_org.set_alternate_ids(RepeatedField::from_vec(
             update_org
                 .alternate_ids()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(AlternateId::into_proto)
                 .collect::<Result<Vec<protos::pike_state::AlternateId>, ProtoConversionError>>()?,
         ));
@@ -703,8 +703,8 @@ impl FromNative<UpdateOrganizationAction> for protos::pike_payload::UpdateOrgani
         proto_update_org.set_metadata(RepeatedField::from_vec(
             update_org
                 .metadata()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(KeyValueEntry::into_proto)
                 .collect::<Result<Vec<protos::pike_state::KeyValueEntry>, ProtoConversionError>>(
                 )?,
