@@ -147,8 +147,8 @@ impl FromProto<protos::schema_payload::SchemaCreateAction> for SchemaCreateActio
             description: schema_create.get_description().to_string(),
             properties: schema_create
                 .get_properties()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(PropertyDefinition::from_proto)
                 .collect::<Result<Vec<PropertyDefinition>, ProtoConversionError>>()?,
         })
@@ -163,7 +163,7 @@ impl FromNative<SchemaCreateAction> for protos::schema_payload::SchemaCreateActi
         proto_schema_create.set_description(schema_create.description().to_string());
         proto_schema_create.set_properties(
             RepeatedField::from_vec(
-            schema_create.properties().to_vec().into_iter()
+            schema_create.properties().iter().cloned()
             .map(PropertyDefinition::into_proto)
             .collect::<Result<Vec<protos::schema_state::PropertyDefinition>, ProtoConversionError>>()?,));
 
@@ -274,8 +274,8 @@ impl FromProto<protos::schema_payload::SchemaUpdateAction> for SchemaUpdateActio
             schema_name: schema_update.get_schema_name().to_string(),
             properties: schema_update
                 .get_properties()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(PropertyDefinition::from_proto)
                 .collect::<Result<Vec<PropertyDefinition>, ProtoConversionError>>()?,
         })
@@ -289,7 +289,7 @@ impl FromNative<SchemaUpdateAction> for protos::schema_payload::SchemaUpdateActi
         proto_schema_update.set_schema_name(schema_update.schema_name().to_string());
         proto_schema_update.set_properties(
             RepeatedField::from_vec(
-            schema_update.properties().to_vec().into_iter()
+            schema_update.properties().iter().cloned()
             .map(PropertyDefinition::into_proto)
             .collect::<Result<Vec<protos::schema_state::PropertyDefinition>, ProtoConversionError>>()?,));
 
@@ -421,8 +421,8 @@ impl FromProto<protos::schema_state::PropertyDefinition> for PropertyDefinition
             enum_options: property_definition.get_enum_options().to_vec(),
             struct_properties: property_definition
                 .get_struct_properties()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(PropertyDefinition::from_proto)
                 .collect::<Result<Vec<PropertyDefinition>, ProtoConversionError>>()?,
         })
@@ -443,7 +443,7 @@ impl FromNative<PropertyDefinition> for protos::schema_state::PropertyDefinition
         ));
         proto_property_definition.set_struct_properties(
             RepeatedField::from_vec(
-            property_definition.struct_properties().to_vec().into_iter()
+            property_definition.struct_properties().iter().cloned()
             .map(PropertyDefinition::into_proto)
             .collect::<Result<Vec<protos::schema_state::PropertyDefinition>, ProtoConversionError>>()?,));
         Ok(proto_property_definition)
@@ -658,8 +658,8 @@ impl FromProto<protos::schema_state::PropertyValue> for PropertyValue {
             enum_value: property_value.get_enum_value(),
             struct_values: property_value
                 .get_struct_values()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(PropertyValue::from_proto)
                 .collect::<Result<Vec<PropertyValue>, ProtoConversionError>>()?,
             lat_long_value: property_value.get_lat_long_value().clone().into_native()?,
@@ -680,8 +680,8 @@ impl FromNative<PropertyValue> for protos::schema_state::PropertyValue {
         proto_property_value.set_struct_values(RepeatedField::from_vec(
             property_value
                 .struct_values()
-                .to_vec()
-                .into_iter()
+                .iter()
+                .cloned()
                 .map(PropertyValue::into_proto)
                 .collect::<Result<Vec<protos::schema_state::PropertyValue>, ProtoConversionError>>(
                 )?,
